%global min_libsolv_ver 0.6.35-1

# Small macro to define (Build)Requires for solv tools
%global req_solv_tool() \
BuildRequires:  %{_bindir}/%{1} \
Requires:       %{_bindir}/%{1}
# End macro

Name:           libzypp
Version:        17.8.1
Release:        1%{?dist}
Summary:        A package management library

License:        GPLv2+
URL:            https://en.opensuse.org/Portal:Libzypp
Source0:        https://github.com/openSUSE/%{name}/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  %{_bindir}/asciidoctor
BuildRequires:  %{_bindir}/xsltproc
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  gpgme-devel
BuildRequires:  pkgconfig(rpm)
BuildRequires:  pkgconfig(popt)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libproxy-1.0)
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  boost-devel
BuildRequires:  glib2-devel
BuildRequires:  gettext
BuildRequires:  libsolv-devel >= %{min_libsolv_ver}
BuildRequires:  libsolv-tools >= %{min_libsolv_ver}

# Ensure specific functionality is enabled for libsolv that libzypp needs
%req_solv_tool  repo2solv
%req_solv_tool  rpmmd2solv
%req_solv_tool  helix2solv
%req_solv_tool  susetags2solv
%req_solv_tool  comps2solv
%req_solv_tool  appdata2solv

Requires:       libsolv-tools >= %{min_libsolv_ver}
Requires:       zypp-common = %{version}-%{release}
Requires:       zypp-plugins = %{version}-%{release}
Requires:       zypp-tools = %{version}-%{release}
Requires:       gnupg2

%description
libzypp is a library for package management built on top of the
libsolv library. It is the foundation for the Zypper package manager.

%package -n zypp-common
Summary:        Common files for ZYpp
BuildArch:      noarch

%description -n zypp-common
This package provides the common files expected by %{name}
and its consumers.

%package -n zypp-plugins
Summary:        Plugins for %{name} users
# Features we provide (update doc/autoinclude/FeatureTest.doc):
Provides:       libzypp(plugin) = 0.1
Provides:       libzypp(plugin:appdata) = 0
Provides:       libzypp(plugin:commit) = 1
Provides:       libzypp(plugin:services) = 1
Provides:       libzypp(plugin:system) = 1
Provides:       libzypp(plugin:urlresolver) = 0
Provides:       libzypp(repovarexpand) = 1.1
Requires:       zypp-common = %{version}-%{release}
BuildArch:      noarch

%description -n zypp-plugins
The zypp-plugins package contains various plugin binaries used
by consumers of %{name}.

%package -n zypp-tools
Summary:        Tools for %{name} users
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n zypp-tools
The zypp-tools package contains tools shipped for consumers
of %{name} to use.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       libsolv-devel%{?_isa} >= %{min_libsolv_ver}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        devel-doc
Summary:        Documentation for development using %{name}
BuildArch:      noarch

%description    devel-doc
The %{name}-devel-doc package contains documentation for
developing applications that use %{name}.

%prep
%autosetup -p1

# Use correct libexecdir
find -type f -exec sed -i -e "s|/usr/lib/zypp|%{_libexecdir}/zypp|g" {} ';'
find -type f -exec sed -i -e "s|\${CMAKE_INSTALL_PREFIX}/lib/zypp|\${CMAKE_INSTALL_PREFIX}/libexec/zypp|g" {} ';'

%build
%cmake . -B"%{_vpath_builddir}" -DCMAKE_BUILD_TYPE=RelWithDebInfo -DDOC_INSTALL_DIR=%{_docdir}
%make_build -C %{_vpath_builddir}
%make_build -C %{_vpath_builddir}/doc/autodoc
%make_build -C %{_vpath_builddir}/po translations
%make_build -C %{_vpath_builddir}/tests

%install
%make_install -C %{_vpath_builddir}
%make_install -C %{_vpath_builddir}/doc/autodoc
%make_install -C %{_vpath_builddir}/po
%find_lang zypp

find %{buildroot} -name '*.la' -exec rm -f {} ';'

# Repositories are installed in /etc/yum.repos.d by fedora-repos
ln -sf %{_sysconfdir}/yum.repos.d %{buildroot}%{_sysconfdir}/zypp/repos.d

# Create directories expected by libzypp
mkdir -p %{buildroot}%{_sysconfdir}/zypp/services.d
mkdir -p %{buildroot}%{_sysconfdir}/zypp/systemCheck.d
mkdir -p %{buildroot}%{_sysconfdir}/zypp/vendors.d
mkdir -p %{buildroot}%{_sysconfdir}/zypp/multiversion.d
mkdir -p %{buildroot}%{_sysconfdir}/zypp/credentials.d
mkdir -p %{buildroot}%{_libexecdir}/zypp
mkdir -p %{buildroot}%{_libexecdir}/zypp/plugins
mkdir -p %{buildroot}%{_libexecdir}/zypp/plugins/appdata
mkdir -p %{buildroot}%{_libexecdir}/zypp/plugins/commit
mkdir -p %{buildroot}%{_libexecdir}/zypp/plugins/services
mkdir -p %{buildroot}%{_libexecdir}/zypp/plugins/system
mkdir -p %{buildroot}%{_libexecdir}/zypp/plugins/urlresolver
mkdir -p %{buildroot}%{_sharedstatedir}/zypp
mkdir -p %{buildroot}%{_sharedstatedir}/zypp/needreboot.d
mkdir -p %{buildroot}%{_localstatedir}/log/zypp
mkdir -p %{buildroot}%{_localstatedir}/cache/zypp

# Remove needreboot file
rm %{buildroot}%{_sharedstatedir}/zypp/needreboot

%check
pushd %{_vpath_builddir}/tests
# Tests need to be compiled first
LD_LIBRARY_PATH=%{buildroot}%{_libdir}:${LD_LIBRARY_PATH} ctest -VV .
popd


%files
%license COPYING
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/cmake/Modules/*

%files devel-doc
%doc %dir %{_docdir}/libzypp
%doc %{_docdir}/libzypp/*

%files -n zypp-common -f zypp.lang
%dir %{_sysconfdir}/zypp
%dir %{_sysconfdir}/zypp/services.d
%dir %{_sysconfdir}/zypp/systemCheck.d
%dir %{_sysconfdir}/zypp/vendors.d
%dir %{_sysconfdir}/zypp/multiversion.d
%dir %{_sysconfdir}/zypp/credentials.d
%{_sysconfdir}/zypp/repos.d
%config(noreplace) %{_sysconfdir}/zypp/zypp.conf
%config(noreplace) %{_sysconfdir}/zypp/systemCheck
%config(noreplace) %{_sysconfdir}/logrotate.d/zypp-history.lr
%dir %{_sharedstatedir}/zypp/
%dir %{_sharedstatedir}/zypp/needreboot.d
%dir %{_localstatedir}/log/zypp
%dir %{_localstatedir}/cache/zypp
%dir %{_libexecdir}/zypp
%{_mandir}/man5/*.5*
%{_datadir}/zypp/

%files -n zypp-plugins
%{_libexecdir}/zypp/plugins/

%files -n zypp-tools
%{_bindir}/zypp-*
%{_mandir}/man1/*.1*


%changelog
* Sat Nov 03 2018 Neal Gompa <ngompa13@gmail.com> - 17.8.1-1
- Rebase to 17.8.1

* Sun Aug 26 2018 Neal Gompa <ngompa13@gmail.com> - 17.6.2-1
- Rebase to 17.6.2 (#1552594)

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 17.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sun Mar 04 2018 Neal Gompa <ngompa13@gmail.com> - 17.2.0-1
- Rebase to 17.2.0 (#1547298)

* Tue Feb 06 2018 Neal Gompa <ngompa13@gmail.com> - 17.1.2-1
- Rebase to 17.1.2 (#1489422)
- Backport fix to fix tests compiled with _GLIBCXX_ASSERTIONS on
- Drop unneeded ldconfig scriptlets
  - See https://fedoraproject.org/wiki/Changes/Removing_ldconfig_scriptlets

* Fri Jan 19 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 16.15.6-2
- Rebuild to pick up OpenSSL 1.1

* Sun Sep 03 2017 Neal Gompa <ngompa13@gmail.com> - 16.15.6-1
- Update to 16.15.6 (#1485326)
- Drop all patches as they are part of this release

* Thu Aug 17 2017 Neal Gompa <ngompa13@gmail.com> - 16.15.3-1
- Update to 16.15.3 (#1480822)
- Backport patches from upstream
  - Fix missing return value
  - Fix typo in changelog
  - Drop RPM 4.4 compatibility code to fix build with RPM 4.14

* Fri Aug 11 2017 Igor Gnatenko <ignatenko@redhat.com> - 16.15.2-4
- Rebuilt after RPM update (№ 3)

* Thu Aug 10 2017 Igor Gnatenko <ignatenko@redhat.com> - 16.15.2-3
- Rebuilt for RPM soname bump

* Thu Aug 10 2017 Igor Gnatenko <ignatenko@redhat.com> - 16.15.2-2
- Rebuilt for RPM soname bump

* Sat Aug 05 2017 Neal Gompa <ngompa13@gmail.com> - 16.15.2-1
- Update to 16.15.2 (#1467000)

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 16.12.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 16.12.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Tue Jun 20 2017 Neal Gompa <ngompa13@gmail.com> - 16.12.0-1
- Update to 16.12.0 (#1444589)

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 16.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Mon Apr 17 2017 Neal Gompa <ngompa13@gmail.com> - 16.6.1-1
- Update to 16.6.1
- Split data content and binaries into subpackages
- Use correct libexecdir
- Add BR for libudev

* Fri Feb 24 2017 Neal Gompa <ngompa13@gmail.com> - 16.4.3-1
- Update to 16.4.3
- Add missing directories to be owned by package
- Add missing dependencies on libsolv-tools

* Mon Dec 12 2016 Neal Gompa <ngompa13@gmail.com> - 16.3.1-1
- Update to 16.3.1
- Bump required libsolv version

* Sat Sep  3 2016 Neal Gompa <ngompa13@gmail.com> - 16.2.2-4
- Add test run conditional

* Sat Aug 27 2016 Neal Gompa <ngompa13@gmail.com> - 16.2.2-3
- Rebuild against libsolv to add suserepo support

* Thu Aug 25 2016 Neal Gompa <ngompa13@gmail.com> - 16.2.2-2
- Add patch to use correct name for repo2solv with Fedora libsolv

* Wed Aug 24 2016 Neal Gompa <ngompa13@gmail.com> - 16.2.2-1
- Update to 16.2.2
- Bump required libsolv version

* Fri Jun 10 2016 Neal Gompa <ngompa13@gmail.com> - 16.0.2-1
- Update to 16.0.2

* Tue Apr 26 2016 Neal Gompa <ngompa13@gmail.com> - 15.22.0-1
- Update to 15.22.0

* Wed Apr  6 2016 Neal Gompa <ngompa13@gmail.com> - 15.21.5-1
- Update to 15.21.5

* Thu Feb  4 2016 Neal Gompa <ngompa13@gmail.com> - 15.21.2-1
- Update to 15.21.2

* Sun Jan 31 2016 Neal Gompa <ngompa13@gmail.com> - 15.21.1-1
- Initial packaging
